<?php
/**
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Teqpay\TeqpayPos\Block;

use Magento\Customer\Model\Session;

class Index extends \Magento\Framework\View\Element\Template
{

	protected $customerSession;

	public function __construct(
		\Magento\Framework\View\Element\Template\Context $context,
		Session $session
	){
		$this->customerSession = $session;
		parent::__construct($context);
	}


    public function getMonths() {
		$months = array();

		for ($i = 1; $i <= 12; $i++) {
			$months[] = array(
				'text'  => strftime('%B', mktime(0, 0, 0, $i, 1, 2000)),
				'value' => sprintf('%02d', $i)
			);
		}

		return $months;
	}

	public function getYears() {
		$years = array();

		$today = getdate();

		for ($i = $today['year']; $i < $today['year'] + 11; $i++) {
			$years[] = array(
				'text'  => strftime('%Y', mktime(0, 0, 0, 1, 1, $i)),
				'value' => strftime('%y', mktime(0, 0, 0, 1, 1, $i))
			);
		}

		return $years;
	}

	public function checkStoreCard()
	{
		return $this->customerSession->getId();

	}

	public function getCards()
	{
		$customer_id = $this->customerSession->getId();
		$customer_id = (int) $customer_id;
		$objectManager = \Magento\Framework\App\ObjectManager::getInstance(); // Instance of object manager
                $resource = $objectManager->get('Magento\Framework\App\ResourceConnection');
                $connection = $resource->getConnection();
                $tableName = $resource->getTableName('sipay_cards'); //gives table name with prefix


				$sql = "Select * FROM " . $tableName . " where customer_id = " . $customer_id;
				$result = $connection->fetchAll($sql); // gives associated array, table fields as key in array.

				return $result;
	}

	public function check3D()
    {
        $result = $this->getToken();
        if($result->status_code == 100)
        {
            return $this->is_3d = $result->data->is_3d;
        }
    }

    private function getToken()
    {

        $api_secret = $this->_scopeConfig->getValue('payment/teqpay_pos/apisecret');
        $api_key = $this->_scopeConfig->getValue('payment/teqpay_pos/apikey');
        $merchant_key = $this->_scopeConfig->getValue('payment/teqpay_pos/merchantkey'); 
        $merchant_id = $this->_scopeConfig->getValue('payment/teqpay_pos/merchantid'); 
        $sandbox = $this->_scopeConfig->getValue('payment/teqpay_pos/sandbox'); 


        
		$url = $sandbox == 1 ? 'https://provisioning.sipay.com.tr/ccpayment/api/token' : 'https://app.sipay.com.tr/ccpayment/api/token';

		$array = [
			'app_id' => $api_key,
			'app_secret' => $api_secret
		];

        return $this->getCurl($url, 'POST', $array);
		
    }

    private function getCurl($url, $method, $array, $header=[]){
        $curl = curl_init();
        curl_setopt_array($curl, array(
            CURLOPT_URL => $url,
            CURLOPT_HTTPHEADER => $header,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => '',
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => $method,
            CURLOPT_POSTFIELDS => $array,
            ));
    
            $response = curl_exec($curl);
    
            curl_close($curl);
            return  json_decode($response);
    }
}