<?php

namespace Teqpay\TeqpayPos\Controller\Sanalpos;

use Magento\Checkout\Model\Type\Onepage;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\App\Request\InvalidRequestException;
use Magento\Quote\Model\QuoteIdToMaskedQuoteIdInterface;

class Response extends \Magento\Framework\App\Action\Action implements \Magento\Framework\App\CsrfAwareActionInterface
{

    protected $_context;
    protected $_pageFactory;
    protected $_jsonEncoder;
    protected $_checkoutSession;
    protected $_customerSession;
    protected $_quote;
    protected $_cartManagement;
    protected $_resultRedirect;
    protected $_resultJsonFactory;
    protected $_quoteRepository;
    protected $_scopeConfig;
    protected $_request;
    protected $_messageManager;
    protected $_guestCartManagement;
    protected $_storeManager;
    protected $_quoteIdToMaskedQuoteId;
    

    public function __construct(
        \Magento\Framework\App\Action\Context $context,
        \Magento\Framework\Json\EncoderInterface $encoder,
        \Magento\Framework\View\Result\PageFactory $pageFactory,
        \Magento\Checkout\Model\Session $checkoutSession,
        \Magento\Customer\Model\Session $customerSession,
        \Magento\Quote\Model\Quote $quote,
        \Magento\Quote\Api\CartManagementInterface $cartManagement,
        \Magento\Framework\Controller\ResultFactory $resultFactory,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        \Magento\Quote\Api\CartRepositoryInterface $quoteRepository,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Framework\App\Request\Http $request,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Checkout\Api\GuestPaymentInformationManagementInterface $guestCartManagement,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        QuoteIdToMaskedQuoteIdInterface $quoteIdToMaskedQuoteId
        
    ) {
        parent::__construct($context);
        $this->_resultJsonFactory = $resultJsonFactory;
        $this->_pageFactory = $pageFactory;
        $this->_jsonEncoder = $encoder;
        $this->_checkoutSession = $checkoutSession;
        $this->_customerSession = $customerSession;
        $this->_quote = $quote;
        $this->_cartManagement = $cartManagement;
        $this->_resultRedirect = $context->getResultFactory();
        $this->_quoteRepository = $quoteRepository;
        $this->_scopeConfig = $scopeConfig;
        $this->_request = $request;
        $this->_messageManager = $messageManager;
        $this->_guestCartManagement = $guestCartManagement;
        $this->_storeManager = $storeManager;
        $this->_quoteIdToMaskedQuoteId = $quoteIdToMaskedQuoteId;
    }

    public function execute()
    {   

        $resultRedirect = $this->_resultRedirect->create(ResultFactory::TYPE_REDIRECT);
        $checkoutSession = $this->_checkoutSession->getQuote();

        $payment_type = $checkoutSession->getPayment()->setMethod('teqpay_pos');

        $this->_quote = $this->_checkoutSession->getQuote();
        $customerId = 0;
        $billingAddress  = $checkoutSession->getBillingAddress();

        if($billingAddress->getEmail()){

            $email = $billingAddress->getEmail();
        
        } else {
  
            $email = $this->_customerSession->getCustomer()->getEmail();
        }


        if($this->_customerSession->isLoggedIn()){
            $customerId = $this->_customerSession->getCustomerId();
        }
        $data = $this->getRequest()->getParams();

        if($data['Result'] == true){
            $check = $this->checkPayment($data['OrderId']);
            if($check === true){
                if($this->_customerSession->isLoggedIn()) {
                    /* Place Order - Login Checkout */
                    $this->_cartManagement->placeOrder($checkoutSession->getId());
    
                } else {
                    $quoteId = $this->getQuoteMaskId($checkoutSession->getId());
                    try {
                        $this->_guestCartManagement->savePaymentInformationAndPlaceOrder($quoteId,$email,$payment_type,$this->_checkoutSession->getBillingAddress());
    
                    } catch(\Exception $e){
                        echo $e->getMessage(); exit;
                    }
                    
    
                }
            } else {
                $this->_messageManager->addErrorMessage($data['ResultMessage']);
                $resultRedirect->setPath('checkout/cart', ['_secure' => true]);
                return $resultRedirect;
            }
            
        } else {
            $this->_messageManager->addErrorMessage($data['ResultMessage']);
            $resultRedirect->setPath('checkout/cart', ['_secure' => true]);
            return $resultRedirect;
        }


            
        $resultRedirect->setPath('checkout/onepage/success', ['_secure' => true]);
        return $resultRedirect;

    }

    private function checkPayment($order_id)
    {
        $sandbox = $this->_scopeConfig->getValue('payment/teqpay_pos/sandbox'); 
        $url = $sandbox == 1 ? 'https://merchant-test.teqpay.com/api/teqpay/paymentcheck' : 'https://merchant.teqpay.com/api/teqpay/paymentcheck';


        $post = [
            "orderId" => $order_id,
            "language" => 'TR'
        ];

        $json = json_encode($post);

        $response = $this->curl($url, 'POST', $json);

        if($response['Details']['OrderStatusCode'] == 1){
            return true;
        }

        return false;
    }

    private function curl($url, $method, $json)
    {
        $secret_key = $this->_scopeConfig->getValue('payment/teqpay_pos/apisecret');
        $api_key = $this->_scopeConfig->getValue('payment/teqpay_pos/apikey');

        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_VERBOSE => true,
            CURLOPT_URL => $url,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => "",
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => $method,
            CURLOPT_POSTFIELDS => $json,
            CURLOPT_HTTPHEADER => [
              "Content-Type: application/json",
              "ApiKey: {$api_key}",
              "SecretKey: {$secret_key}",
            ]
        ]);

        $response = curl_exec($curl);
		$response = json_decode($response, true);
        curl_close($curl);

        return $response;
    }


    /**
     * @inheritDoc
     */
    public function createCsrfValidationException(
        RequestInterface $request
    ): ?InvalidRequestException {
        return null;
    }

    /**
     * @inheritDoc
     */
    public function validateForCsrf(RequestInterface $request): ?bool
    {
        return true;
    }

    private function getQuoteMaskId($quoteId)
    {
        $maskedId = null;
        try {
            $maskedId = $this->_quoteIdToMaskedQuoteId->execute($quoteId);
        } catch (NoSuchEntityException $exception) {
            throw new LocalizedException(__('Current user does not have an active cart.'));
        }

        return $maskedId;
    }
}