<?php
/**
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */
namespace Teqpay\TeqpayPos\Model\Adminhtml\Source;

use Magento\Payment\Model\Method\AbstractMethod;

/**
 * Class PaymentAction
 */
class Installments implements \Magento\Framework\Option\ArrayInterface
{

    protected $_scopeConfig;

    public function __construct(\Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig)
    {
        $this->_scopeConfig = $scopeConfig;
    }

    public function toOptionArray()
    {
        $api_secret = $this->_scopeConfig->getValue('payment/teqpay_pos/apisecret');
        $api_key = $this->_scopeConfig->getValue('payment/teqpay_pos/apikey');
        $merchantkey = $this->_scopeConfig->getValue('payment/teqpay_pos/merchantkey'); 
        $merchant_id = $this->_scopeConfig->getValue('payment/teqpay_pos/merchantid'); 
        $sandbox = $this->_scopeConfig->getValue('payment/teqpay_pos/sandbox'); 
        if(empty($api_key) || empty($api_secret) || empty($merchantkey)){
            return [];
        }
        
        return $this->getInstallment();
    }

    public function getInstallment(){



        $inst = [];

        $api_secret = $this->_scopeConfig->getValue('payment/teqpay_pos/apisecret');
        $api_key = $this->_scopeConfig->getValue('payment/teqpay_pos/apikey');
        $merchantkey = $this->_scopeConfig->getValue('payment/teqpay_pos/merchantkey'); 
        $merchant_id = $this->_scopeConfig->getValue('payment/teqpay_pos/merchantid'); 
        $sandbox = $this->_scopeConfig->getValue('payment/teqpay_pos/sandbox'); 
        $post = [
            'app_id' => $api_key,

            'app_secret' => $api_secret,
        ];


        $url = $sandbox == 1 ? 'https://provisioning.sipay.com.tr/ccpayment/api/token' : 'https://app.sipay.com.tr/ccpayment/api/token';

        $token = $this->getCurl($url, 'POST', $post);

        $token = $token->data->token;

        $a['merchant_key'] = $merchantkey;
        $url = $sandbox == 1 ? 'https://provisioning.sipay.com.tr/ccpayment/api/installments' : 'https://app.sipay.com.tr/ccpayment/api/installments';
        $headers = ['Accept: application/json', 'Content-Type: application/json', "Authorization: Bearer $token"];
        $installments = $this->getCurl($url, 'POST', json_encode($a), $headers);
        

        
        foreach($installments->installments as $key => $installment){
            $inst[$key]['value'] = $installment;
            $inst[$key]['label'] = $installment;
            
        }

        return $inst;

        
    }

    


    public function getCurl($url, $method, $array, $header = [])
    {
        $curl = curl_init();
        curl_setopt_array($curl, [
            CURLOPT_URL => $url,
            CURLOPT_HTTPHEADER => $header,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_ENCODING => '',
            CURLOPT_MAXREDIRS => 10,
            CURLOPT_TIMEOUT => 0,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
            CURLOPT_CUSTOMREQUEST => $method,
            CURLOPT_POSTFIELDS => $array,
        ]);

        $response = curl_exec($curl);

        curl_close($curl);
        return json_decode($response);
    }
}
