define(
    [
        'underscore',
        'Magento_Checkout/js/view/payment/default',
        'Magento_Payment/js/model/credit-card-validation/credit-card-data',
        'Magento_Payment/js/model/credit-card-validation/credit-card-number-validator',
        'mage/translate',
        'jquery',
        'mage/validation'
    ],
    function (_, Component, creditCardData, cardNumberValidator, $t, $) {
        'use strict';
        
        return Component.extend({
            defaults: {
                template: 'Teqpay_TeqpayPos/payment/teqpay',
                creditCardType: '',
                creditCardExpYear: '',
                creditCardExpMonth: '',

                creditCardHolder: '',
                creditCardInstallment: '',
                creditCardNumber: '',
                creditCardSsStartMonth: '',
                creditCardSsStartYear: '',
                creditCardVerificationNumber: '',
                selectedCardType: null
            },
            initObservable: function () {
                this._super()
                
                    .observe([
                        'creditCardType',
                        'creditCardExpYear',
                        'creditCardExpMonth',
                        'creditCardInstallment',
                        'creditCardNumber',
                        'creditCardVerificationNumber',
                        'creditCardSsStartMonth',
                        'creditCardSsStartYear',
                        'creditCardHolder',
                        'selectedCardType'
                    ]);

                return this;
            },

            initialize: function() {
                var self = this;
                this._super();

                //Set credit card number to credit card data object
                this.creditCardNumber.subscribe(function(value) {
                    var result;
                    self.selectedCardType(null);

                    if (value == '' || value == null) {
                        return false;
                    }
                    result = cardNumberValidator(value);

                    if (!result.isPotentiallyValid && !result.isValid) {
                        return false;
                    }
                    if (result.card !== null) {
                        self.selectedCardType(result.card.type);
                        creditCardData.creditCard = result.card;
                    }

                    if (result.isValid) {
                        creditCardData.creditCardNumber = value;
                        self.creditCardType(result.card.type);
                    }
    
                });

                //Set expiration year to credit card data object
                this.creditCardExpYear.subscribe(function(value) {
                    creditCardData.expirationYear = value;
                });

                //Set expiration month to credit card data object
                this.creditCardExpMonth.subscribe(function(value) {
                    creditCardData.expirationMonth = value;
                });

                this.creditCardInstallment.subscribe(function(value) {
                    creditCardData.installments = value;
                });

                //Set cvv code to credit card data object
                this.creditCardVerificationNumber.subscribe(function(value) {
                    creditCardData.cvvCode = value;
                });

                this.creditCardHolder.subscribe(function(value) {
                    creditCardData.holder = value;
                });
            },

            

            /**
             * @return {jQuery}
             */
            validate: function () {
                return $('form#teqpay').validation() && $('form#teqpay').validation('isValid');
            },

            isActive: function () {
                return true;
            },

            /**
             * Get data
             * @returns {Object}
             */
            getData: function () {
                var parent = this._super(),
                
                paymentData = {};
                paymentData['cvv'] = $('#teqpay_pos_cc_cid').val();
                paymentData['month'] = $('#teqpay_pos_expiration').val();
                paymentData['year'] = $('#teqpay_pos_expiration_yr').val();
                paymentData['installment'] = $('#teqpay_pos_installment').val();
                paymentData['number'] = $('#teqpay_pos_cc_number').val();
                paymentData['holder'] = $('#teqpay_pos_cc_holder').val();
                   
                

                return $.extend(true, parent, {'additional_data': paymentData});
            },

            getCcAvailableTypes: function() {
                return window.checkoutConfig.payment.teqpay_pos.availableTypes['teqpay_pos'];
            },

            fetchJavaScripts: function () {
                return window.checkoutConfig.payment.teqpay_pos.fetchJavaScripts['teqpay_pos']
            },

            getCcMonths: function() {
                return window.checkoutConfig.payment.teqpay_pos.months['teqpay_pos'];
            },

            cardForm: function(){
                return window.checkoutConfig.payment.teqpay_pos.is_api['teqpay_pos'];
            },

            getInstallments: function() {
                return window.checkoutConfig.payment.teqpay_pos.installments['teqpay_pos'];
            },

            getCcYears: function() {
                return window.checkoutConfig.payment.teqpay_pos.years['teqpay_pos'];
            },

            hasVerification: function() {
                return window.checkoutConfig.payment.teqpay_pos.hasVerification['teqpay_pos'];
            },

            submitOrder: function(data, event)
            {
                var self = this;

                if (event) {
                    event.preventDefault();
                }

                if (this.validate() &&
                    this.isPlaceOrderActionAllowed() === true
                ) {
                    $.ajax({
                        url: '/teqpay/sanalpos/session',
                        type: 'POST',
                        data : $('form#teqpay').serialize(),
                    });
                    //console.log(this.cardForm());
                    window.location.replace(window.checkoutConfig.payment.teqpay_pos.redirectUrl['teqpay_pos']);
                }

                return false;
            },

            getCcAvailableTypesValues: function() {
                return _.map(this.getCcAvailableTypes(), function(value, key) {
                    return {
                        'value': key,
                        'type': value
                    }
                });
            },
            getCcMonthsValues: function() {
                return _.map(this.getCcMonths(), function(value, key) {
                    return {
                        'value': key,
                        'month': value
                    }
                });
            },
            getInstallmentValues: function() {
                return _.map(this.getInstallments(), function(value, key) {
                    return {
                        'value': key,
                        'ins': value
                    }
                });
            },
            getCcYearsValues: function() {
                return _.map(this.getCcYears(), function(value, key) {
                    return {
                        'value': key,
                        'year': value
                    }
                });
            }
        });
    }
);